﻿Imports Infragistics.Win.UltraWinEditors
Imports Infragistics.Win
Imports Infragistics.Win.UltraWinGrid

Public Class frmCellValueList

    Private editorsValueList As ValueList = Nothing

    Private Sub UltraGrid1_CellChange(sender As Object, e As Infragistics.Win.UltraWinGrid.CellEventArgs) Handles UltraGrid1.CellChange
        If "FieldType".Equals(e.Cell.Column.Key) Then
            e.Cell.Row.Cells("FieldValue").Value = DBNull.Value

            Dim fieldType As String = e.Cell.Text
            Dim editorsValueList As ValueList = Me.GetEditorsValueList()
            Dim index As Integer = editorsValueList.FindStringExact(fieldType)

            Dim editor As EmbeddableEditorBase = Nothing
            If index >= 0 Then
                editor = DirectCast(editorsValueList.ValueListItems(index).Tag, EmbeddableEditorBase)
            End If

            e.Cell.Row.Cells("FieldValue").Editor = editor
        End If
    End Sub

    Private Sub UltraGrid1_InitializeLayout(sender As Object, e As Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs) Handles UltraGrid1.InitializeLayout
        e.Layout.Bands(0).Columns("FieldType").ValueList = Me.GetEditorsValueList()

        ' Set the Style to DropDownList.
        e.Layout.Bands(0).Columns("FieldType").Style = ColumnStyle.DropDownList

        e.Layout.Bands(0).Columns("FieldType").Width = 150
        e.Layout.Bands(0).Columns("FieldValue").Width = 150

        ' Always show any drop down or editor buttons the editor may have.
        e.Layout.Bands(0).Columns("FieldValue").ButtonDisplayStyle = Infragistics.Win.UltraWinGrid.ButtonDisplayStyle.Always

        ' Set the mask modes. This only effects columns that use EditorWithMask or derived editors.
        e.Layout.Bands(0).Columns("FieldValue").MaskDisplayMode = Infragistics.Win.UltraWinMaskedEdit.MaskMode.IncludeBoth
        e.Layout.Bands(0).Columns("FieldValue").MaskDataMode = Infragistics.Win.UltraWinMaskedEdit.MaskMode.IncludeLiterals
    End Sub

    Private Sub UltraGrid1_InitializeRow(sender As Object, e As Infragistics.Win.UltraWinGrid.InitializeRowEventArgs) Handles UltraGrid1.InitializeRow
        Dim fieldType As String = e.Row.Cells("FieldType").Text
        Dim editorsValueList As ValueList = Me.GetEditorsValueList()
        Dim index As Integer = editorsValueList.FindStringExact(fieldType)

        Dim editor As EmbeddableEditorBase = Nothing
        If index >= 0 Then
            editor = DirectCast(editorsValueList.ValueListItems(index).Tag, EmbeddableEditorBase)
        End If

        e.Row.Cells("FieldValue").Editor = editor
    End Sub

    Private Function GetEditorsValueList() As ValueList

        If Not Nothing Is Me.editorsValueList Then
            Return Me.editorsValueList
        End If

        Dim editor As EmbeddableEditorBase = Nothing
        Dim editorSettings As DefaultEditorOwnerSettings = Nothing
        Dim valueList As ValueList = Nothing

        Me.editorsValueList = New ValueList()

        ' Add an item for Text Editor
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(String)
        editor = New EditorWithText(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add("Text Editor").Tag = editor

        ' Add an item for Color picker.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(Color)
        editor = New ColorPickerEditor(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add("Color").Tag = editor

        ' Add an item for Font picker.
        valueList = New ValueList()
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(String)
        Dim i As Integer
        For i = 0 To System.Drawing.FontFamily.Families.Length - 1
            valueList.ValueListItems.Add(System.Drawing.FontFamily.Families(i).Name)
        Next
        editorSettings.ValueList = valueList
        editor = New FontNameEditor(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add("Font").Tag = editor

        ' Add an item for editing currency.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(Decimal)
        editor = New EditorWithMask(New DefaultEditorOwner(editorSettings))
        editorSettings.MaskInput = "$ -nn,nnn,nnn.nn"
        editorsValueList.ValueListItems.Add(editor, "Currency").Tag = editor

        ' Add an item for editing doubles.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(Double)
        editorSettings.MaskInput = "-nnnnnnnn.nnnn"
        editor = New EditorWithMask(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add(editor, "Double").Tag = editor

        ' Add an item for editing integers.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(Integer)
        editor = New EditorWithMask(New DefaultEditorOwner(editorSettings))
        editorSettings.MaskInput = "-nnnnnnnn"
        editorsValueList.ValueListItems.Add(editor, "Integer").Tag = editor

        ' Add an item for editing IPv4 Address.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(String)
        editor = New EditorWithMask(New DefaultEditorOwner(editorSettings))
        editorSettings.MaskInput = "nnn\.nnn\.nnn\.nnn"
        editorsValueList.ValueListItems.Add(editor, "IPv4 Address").Tag = editor

        ' Add an item for editing phone numbers.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(String)
        editor = New EditorWithMask(New DefaultEditorOwner(editorSettings))
        editorSettings.MaskInput = "(###) ###-####"
        editorsValueList.ValueListItems.Add(editor, "Phone").Tag = editor

        ' Add an item that uses Yes/No drop down.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(Boolean)
        valueList = New ValueList()
        valueList.ValueListItems.Add(True, "Yes")
        valueList.ValueListItems.Add(False, "No")
        editorSettings.ValueList = valueList
        editor = New EditorWithCombo(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add(editor, "Drop-down Yes/No Options").Tag = editor

        ' Add an item that uses Yes/No Option Set.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(Boolean)
        valueList = New ValueList()
        valueList.ValueListItems.Add(True, "Yes")
        valueList.ValueListItems.Add(False, "No")
        editorSettings.ValueList = valueList
        editor = New OptionSetEditor(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add(editor, "Yes/No Option Set").Tag = editor

        ' Add an item that uses checkbox.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(Boolean)
        editor = New CheckEditor(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add(editor, "True/False Checkbox").Tag = editor

        ' Add an item that uses tri-state checkbox. DBNull means it's in a intermediate
        ' state.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(Boolean)
        editor = New CheckEditor(New DefaultEditorOwner(editorSettings))
        DirectCast(editor, CheckEditor).ThreeState = True
        editorsValueList.ValueListItems.Add(editor, "True/False/DBNull Checkbox").Tag = editor

        ' Add an item for editing date.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(DateTime)
        editorSettings.MaskInput = "mm/dd/yyyy"
        editor = New DateTimeEditor(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add(editor, "Date").Tag = editor

        ' Add an item for editing time.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(DateTime)
        editorSettings.MaskInput = "hh:mm:ss tt"
        editor = New EditorWithMask(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add(editor, "Time").Tag = editor

        ' Add an item for editing both date and time.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(DateTime)
        editorSettings.MaskInput = "mm/dd/yy hh:mm:ss"
        editor = New DateTimeEditor(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add(editor, "Date & Time").Tag = editor

        ' Add an item for displaying progress. Progressbar editor is read-only and does
        ' not support editing.
        editorSettings = New DefaultEditorOwnerSettings()
        editorSettings.DataType = GetType(Integer)
        editor = New Infragistics.Win.UltraWinProgressBar.ProgressBarEditor(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add(editor, "Progress Bar").Tag = editor

        ' Add a drop down that maps data to display text using value list. This particular 
        ' value list maps 0 data value to text "Zero", 1 data value to text "One" and so on.
        ' What gets set on the bound datasource when a cell is modified is the data value
        ' even though the user sees the display text.
        editorSettings = New DefaultEditorOwnerSettings()
        valueList = New ValueList()
        valueList.ValueListItems.Add(0, "Zero")
        valueList.ValueListItems.Add(1, "One")
        valueList.ValueListItems.Add(2, "Two")
        valueList.ValueListItems.Add(3, "Three")
        valueList.ValueListItems.Add(4, "Four")
        valueList.ValueListItems.Add(5, "Five")
        editorSettings.ValueList = valueList
        editorSettings.DataType = GetType(Integer)
        editor = New EditorWithCombo(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add(editor, "Drop-down using ValueList").Tag = editor

        ' Add a drop down that maps data to display text using UltraDropDown. Following code
        ' creates an UltraDropDown and binds it to an array of Record objects. Record object
        ' is defined further below in this file. What gets set on the bound datasource when 
        ' a cell is modified is the data value which is associated with the ValueMember field.
        editorSettings = New DefaultEditorOwnerSettings()
        Dim dropDown As UltraDropDown = New UltraDropDown()
        dropDown.Visible = False
        Me.Controls.Add(dropDown)
        dropDown.DataSource = New Record() {New Record("Cust 1"), New Record("Cust 2"), New Record("Cust 3"), New Record("Cust 4")}
        ' Set the Value member. Cell values of this column are used as data.
        dropDown.ValueMember = "ID"
        ' Set the Data member. Cell values of this column are dispalyed in the cells.
        dropDown.DisplayMember = "Data"
        dropDown.DisplayLayout.Override.CellAppearance.BackColor = Color.LightYellow
        dropDown.DisplayLayout.Override.CellAppearance.BackColor2 = Color.Yellow
        dropDown.DisplayLayout.Override.CellAppearance.BackGradientStyle = GradientStyle.ForwardDiagonal
        editorSettings.ValueList = dropDown
        editorSettings.DataType = GetType(Integer)
        editor = New EditorWithCombo(New DefaultEditorOwner(editorSettings))
        editorsValueList.ValueListItems.Add(editor, "Drop-down using UltraDropDown").Tag = editor

        Return Me.editorsValueList
    End Function

    Private Sub frmCellValueList_Load(sender As System.Object, e As System.EventArgs) Handles MyBase.Load

        Dim dt As DataTable = New DataTable()

        dt.Columns.Add("FieldType", GetType(String))
        dt.Columns.Add("FieldValue", GetType(Object))

        dt.Rows.Add(New Object() {"Text Editor", "Text"})
        dt.Rows.Add(New Object() {"Color", Color.Blue})
        dt.Rows.Add(New Object() {"Font", Me.Font.Name})
        dt.Rows.Add(New Object() {"Currency", CType(100.0, Decimal)})
        dt.Rows.Add(New Object() {"Double", 100.0})
        dt.Rows.Add(New Object() {"Integer", 100})
        dt.Rows.Add(New Object() {"IPv4 Address", "192.168.1.1"})
        dt.Rows.Add(New Object() {"Phone", "(123) 456-7890"})
        dt.Rows.Add(New Object() {"Drop-down Yes/No Options", False})
        dt.Rows.Add(New Object() {"Yes/No Option Set", False})
        dt.Rows.Add(New Object() {"True/False Checkbox", True})
        dt.Rows.Add(New Object() {"True/False/DBNull Checkbox", DBNull.Value})
        dt.Rows.Add(New Object() {"Date", DateTime.Now})
        dt.Rows.Add(New Object() {"Time", DateTime.Now})
        dt.Rows.Add(New Object() {"Date & Time", DateTime.Now})
        dt.Rows.Add(New Object() {"Drop-down using ValueList", 4})
        dt.Rows.Add(New Object() {"Drop-down using UltraDropDown", 2})
        dt.Rows.Add(New Object() {"Progress Bar", 75})

        Me.UltraGrid1.DataSource = dt

    End Sub
End Class